@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: Album.php 18010 2008-09-16 08:47:36Z JensT $
+ * $Id: Album.php 18624 2008-11-11 01:14:03Z JensT $
  */
 
 class Album {
@@ -1108,7 +1108,6 @@ class Album {
 		if ($gallery->app->emailOn == 'yes' && $success && $msg) {
 			if (!is_array($msg)) {
 				echo gallery_error(gTranslate('core', "msg should be an array!"));
-				vd($msg);
 				return $success;
 			}
 
@@ -3394,16 +3393,13 @@ class Album {
 	}
 
 	function getVotingIdByIndex($index) {
-		$albumName = $this->getAlbumName($index);
+		$photo = $this->getPhoto($index);
 
-		if($albumName === null) {
-			$vote_id = null;
-		}
-		elseif (!empty($albumName)) {
-			$vote_id = "album.$albumName";
+		if ($photo->isAlbum()) {
+			$vote_id = 'album.' . $photo->getAlbumName();
 		}
 		else {
-			$vote_id = "item.".$this->getPhotoId($index);
+			$vote_id = 'item.' . $photo->getPhotoId();
 		}
 
 		return $vote_id;
@@ -3690,6 +3686,25 @@ class Album {
 		array_pop($photo->imageAreas);
 	}
 
+	/**
+	 * Delete all imageareas from a photo.
+	 *
+	 * @param  integer $photo_index 	integer	albumitem index
+	 * @return boolean			True if all imageareas are deleted.
+	 *                                      False if not imageareas existed.
+	 */
+	function deleteAllImageAreas($photo_index) {
+		$photo = &$this->getPhoto($photo_index);
+
+		if(!isset($photo->imageAreas)) {
+			return false;
+		}
+		else {
+			unset($photo->imageAreas);
+			return true;
+		}
+	}
+
 	/**
 	 * Updates an imagearea of an album item
 	 * @param   $photo_index  integer    albumitem index
