@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: modules.php 17825 2008-08-06 23:31:55Z JensT $
+ * $Id: modules.php 18426 2008-11-02 02:09:39Z JensT $
  */
 
 /*
@@ -33,7 +33,17 @@ if (isset($_REQUEST['phpEx'])) {
 
 define('MODULES_PATH', './modules/');
 
-switch ($_REQUEST['op']) {
+foreach (array('op', 'name', 'file') as $varname) {
+	if (isset($_GET[$varname])) {
+		$$varname = $_GET[$varname];
+	}
+	elseif (isset($_POST[$varname])) {
+		$$varname = $_POST[$varname];
+	}
+}
+
+
+switch ($op) {
 	case 'modload':
 		// Added with changes in Security for PhpBB2.
 		define('IN_PHPBB', true);
@@ -52,11 +62,6 @@ switch ($_REQUEST['op']) {
 		//
 		// End session management
 
-		// phpBB may unset() these if we set them before loading
-		// their include files.
-		$name = $_REQUEST['name'];
-		$file = $_REQUEST['file'];
-
 		// Security fix
 		if (ereg("\.\.",$name) || ereg("\.\.",$file)) {
 			echo 'Nice try :-)';
