@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: edit_appearance.php 17806 2008-08-06 16:16:29Z JensT $
+ * $Id: edit_appearance.php 18730 2008-11-17 23:03:22Z JensT $
  */
 
 require_once(dirname(__FILE__) . '/init.php');
@@ -32,6 +32,7 @@ if (! isset($gallery->album) || ! isset($gallery->session->albumName)) {
 if(! $gallery->user->canWriteToAlbum($gallery->album)) {
 	printPopupStart(gTranslate('core', "Album Properties"));
 	showInvalidReqMesg(gTranslate('core', "You are not allowed to perform this action!"));
+	includeHtmlWrap("popup.footer");
 	exit;
 }
 
@@ -173,7 +174,6 @@ if (getRequestVar('save')) {
 	$reloadOpener = true;
 }
 
-
 /* Custom / Extra Fields */
 function num_special_fields($extra_fields) {
 	$num_special_fields = 0;
@@ -320,7 +320,7 @@ foreach ($properties as $key => $val) {
 
 </form>
 
-</div>
+<?php includeHtmlWrap("popup.footer"); ?>
 
 </body>
-</html>
+</html>
\ No newline at end of file
