@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: edit_field.php 17806 2008-08-06 16:16:29Z JensT $
+ * $Id: edit_field.php 18730 2008-11-17 23:03:22Z JensT $
  */
 
 require_once(dirname(__FILE__) . '/init.php');
@@ -38,6 +38,7 @@ if (! isset($gallery->album) || ! isset($gallery->session->albumName) ||
 if (!$gallery->user->canChangeTextOfAlbum($gallery->album)) {
 	printPopupStart(gTranslate('core', "Edit texts"));
 	echo showInvalidReqMesg(gTranslate('core', "You are not allowed to perform this action!"));
+	includeHtmlWrap("popup.footer");
 	exit;
 }
 
@@ -63,7 +64,7 @@ echo gSubmit('save', gTranslate('core', "Save"));
 echo gButton('cancel', gTranslate('core', "Cancel"), 'parent.close()');
 ?>
 	</form>
-</div>
-<?php print gallery_validation_link("edit_field.php",true,array('field' => $field)); ?>
+
+<?php includeHtmlWrap("popup.footer"); ?>
 </body>
 </html>
