@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: setup.php 17982 2008-09-09 21:24:10Z JensT $
+ * $Id: setup.php 18419 2008-11-01 15:42:05Z JensT $
  */
 
 function evenOdd_row($fields) {
@@ -1943,6 +1943,7 @@ function placeholderDescription() {
  * Returns a status code base on the given resultset
  *
  * 0 - success
+ * 3 - information
  * 5 - warning, optional
  * 10 - serious warning, but optional
  * 51 - serious warning
@@ -1960,6 +1961,10 @@ function getCheckStatus($result, $check) {
 		return 0;
 	}
 
+	if (isset($check['information'])) {
+		return 3;
+	}
+		
 	if (isset($check['optional']) && $check['optional']) {
 		if (isset($check["serious"]) && $check["serious"]) {
 			if(empty($fail)) {
