@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: move_album.php 17806 2008-08-06 16:16:29Z JensT $
+ * $Id: move_album.php 18730 2008-11-17 23:03:22Z JensT $
  */
 
 require_once(dirname(__FILE__) . '/init.php');
@@ -31,6 +31,7 @@ if (! isset($gallery->album) || ! isset($gallery->session->albumName)
 {
 	printPopupStart(gTranslate('core', "Move Top Album"));
 	showInvalidReqMesg();
+	includeHtmlWrap("popup.footer");
 	exit;
 }
 
@@ -38,6 +39,7 @@ if (! isset($gallery->album) || ! isset($gallery->session->albumName)
 if (!$gallery->user->canWriteToAlbum($gallery->album)) {
 	printPopupStart(gTranslate('core', "Move Top Album"));
 	showInvalidReqMesg(gTranslate('core', "You are not allowed to perform this action!"));
+	includeHtmlWrap("popup.footer");
 	exit;
 }
 
@@ -159,10 +161,10 @@ echo "</form>";
 
 } // End Reorder
 
+
+includeHtmlWrap("popup.footer");
+
 ?>
 
-</div>
-
-<?php print gallery_validation_link("move_album.php", true, array('index' => $index)); ?>
 </body>
 </html>
