@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: fs_win32.php 17985 2008-09-13 20:09:04Z JensT $
+ * $Id: fs_win32.php 18053 2008-09-23 01:12:07Z JensT $
  */
 
 /**
@@ -115,7 +115,7 @@ function fs_opendir($path, $withDebug = true) {
 	}
 	else {
 		if($withDebug) {
-			echo "\<br>". gallery_error(sprintf(gTranslate('core', "Gallery was not able to open dir: %s. <br>Please check permissions and existence"), $path));
+			echo "\<br>". gallery_error(sprintf(gTranslate('common', "Gallery was not able to open dir: %s. <br>Please check permissions and existence"), $path));
 		}
 
 		return false;
