@@ -1,5 +1,5 @@
 #!/bin/bash
-# $Id: edit_changelog.sh,v 1.9.2.1 2005/08/08 20:35:57 jenst Exp $
+# $Id: edit_changelog.sh 12386 2005-12-23 19:20:39Z jenst $
 
 esc=`echo -en "\033"`
 tab="${esc}[5G"
@@ -48,11 +48,12 @@ for all_CF in $Cfiles ; do
 	echo "$tab Updating ..."
 	echo "" >> $all_CF
 #	echo "===============================================================================" >> $all_CF
-	echo "2005-08-08 Jens Tkotz <jens AT peino DOT de> 1.5.1-RC2-cvs-b12" >> $all_CF
+	echo "2005-10-10 Jens Tkotz <jens AT peino DOT de> 1.5.2-cvs-b54" >> $all_CF
 	echo "" >> $all_CF
 #	echo " * Release of Gallery 1.5-RC2 langpack" >> $all_CF
-	echo " * Changed format to be analog to phpDoc." >> $all_CF
-	echo " * Updated Version Numbers and sync against latest code" >> $all_CF
+	echo " * Updated to latest code. Added -common translation." >> $all_CF
+	echo " * Note: Files needs to be updated !!" >> $all_CF
+#	echo " * Updated Version Numbers and sync against latest code" >> $all_CF
 #	echo "===============================================================================" >> $all_CF
 	echo "" >> $all_CF
 #read trash
