@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: user_preferences.php 17807 2008-08-06 16:30:47Z JensT $
+ * $Id: user_preferences.php 18730 2008-11-17 23:03:22Z JensT $
  */
 
 require_once(dirname(__FILE__) . '/init.php');
@@ -33,6 +33,7 @@ list($saveOK) = getRequestVar('saveOK');
 if (!$gallery->user->isLoggedIn()) {
 	printPopupStart(gTranslate('core', "Change User Preferences"), '', 'left');
 	showInvalidReqMesg(gTranslate('core', "You are not allowed to perform this action!"));
+	includeHtmlWrap("popup.footer");
 	exit;
 }
 
@@ -161,7 +162,6 @@ include(dirname(__FILE__) . '/html/userData.inc');
 </div>
 </form>
 
-</div>
 <script type="text/javascript">
 <!--
 // position cursor in top form field
@@ -169,7 +169,7 @@ document.usermodify_form.uname.focus();
 //-->
 </script>
 
-<?php print gallery_validation_link("user_preferences.php"); ?>
+<?php includeHtmlWrap("popup.footer"); ?>
 
 </body>
-</html>
+</html>
\ No newline at end of file
