@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: view_album.php 17941 2008-08-28 00:33:27Z jenst $
+ * $Id: view_album.php 18062 2008-09-25 17:25:22Z JensT $
 */
 
 require_once(dirname(__FILE__) . '/init.php');
@@ -285,7 +285,7 @@ if (!empty($adminCommands)) {
 
 if ($gallery->album->fields["slideshow_type"] != "off" &&
    ($numPhotos != 0 || ($numVisibleItems != 0 && $gallery->album->fields['slideshow_recursive'] == "yes"))) {
-	$iconText = getIconText('display.gif', gTranslate('core', "Slideshow"));
+	$iconText = getIconText('monitor.png', gTranslate('core', "Slideshow"));
 	$iconElements[] = '<a href="'
 	. makeGalleryUrl("slideshow.php",
 	array("set_albumName" => $albumName)) .'">'. $iconText .'</a>';
@@ -297,7 +297,7 @@ if (checkRequirements('comments_enabled', 'hasComments', 'comments_overview_for_
 		makeGalleryUrl("view_comments.php", array("set_albumName" => $gallery->session->albumName)),
 		gTranslate('core', "View&nbsp;comments"),
 		array(),
-		'view_comment.gif',
+		'comments.png',
 		true
 	);
 }
